@@ -18,7 +18,10 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/identity", "0.9.3", __name__[0:-6], "identity@0.9.3.jsii.tgz"
+    "@aws-prototyping-sdk/identity",
+    "0.10.1",
+    __name__[0:-6],
+    "identity@0.10.1.jsii.tgz",
 )
 
 __all__ = [
